function out = get_cov_matrix_hv(BhvExp,Ns)

  % This function calculates the random error covariance matrix 
  % of the vector b according to Eq. 34.
  %
  % INPUT VARIABLES:
  %
  % BhvExp is the 'true' 2x2 covariance matrix
  % Ns is the number of spectra averaged non-coherently
  %
  % OUTPUT:
  %
  % out is 4x4 error covariance matrix
  % EXAMPLE:
  %
  % BhvExp(1,1) = 2; % B_{hh}
  % BhvExp(2,2) = 1; % B_{vv}
  % BhvExp(1,2) = 0.5 + 1i*0.1; % R_{hv} + 1i*J_{hv}
  % BhvExp(2,1) = conj(BhvExp(1,2));
  %
  % Ns = 10;
  %
  % get_cov_matrix_hv(BhvExp,Ns)
  %
  % The output of the code is as follows:
  %
  % 0.4000    0.1000    0.0200    0.0260
  % 0.1000    0.1120    0.0050    0.0500
  % 0.0200    0.0050    0.0880    0.0100
  % 0.0260    0.0500    0.0100    0.1000
  
  U = get_operator_for_sec_specfific_basis(BhvExp);
  A = get_operator_cccxxx_to_hhhvvv(U);
  
  Bc = coh_matrix_in_orthogonal_basis_from_formulas(BhvExp,U);
  
  E = error_covariance_matrix_cc_xx(Bc,Ns);

  out = A * E * A';
  
end

function E = error_covariance_matrix_cc_xx(Bc,Nav)

  mcc = Bc(1,1);
  vcc = mcc^2/Nav;
  
  mxx = Bc(2,2);
  vxx = mxx^2/Nav;
  
  srmcc = mcc.^2 + vcc;
  srmxx = mxx.^2 + vxx;
  
  mrecx = 0;
  mimcx = 0;
  
  vrecx = Bc(1,1) * Bc(2,2) / Nav / 2;
  vimcx = Bc(1,1) * Bc(2,2) / Nav / 2;
  
  E = diag([vcc vrecx vimcx vxx]);
  
%  mrehv = a * mcc + d * mxx;
%  vrehv = a^2 * srmcc + (b^2 + c^2) * vrecx + 2*a*d*mcc*mxx + d^2 * srmxx - mrehv^2;
%  
%  mimhv = a * mcc + d * mxx;
%  vimhv = a^2 * srmcc + (b^2 + c^2) * vrecx + 2*a*d*mcc*mxx + d^2 * srmxx - mimhv^2;

end

function A = get_operator_cccxxx_to_hhhvvv(U)
  
  a = U(1,1)^2;
  b = 2 * U(1,1) * real(U(1,2));
  c = 2 * U(1,1) * imag(U(1,2));
  d = abs(U(1,2))^2;
  
  A(1,:) = [a b c d];
  
  a = - U(1,1) * real(U(1,2));
  b = U(1,1)^2 - real(U(1,2))^2 + imag(U(1,2))^2;
  c = -2 * real(U(1,2))*imag(U(1,2));
  d = U(1,1) * real(U(1,2));
  
  A(2,:) = [a b c d];
  
  a = - U(1,1) * imag(U(1,2));
  c = U(1,1)^2 + real(U(1,2))^2 - imag(U(1,2))^2;
  b = -2 * real(U(1,2))*imag(U(1,2));
  d = U(1,1) * imag(U(1,2));
  
  A(3,:) = [a b c d];
  
  a = abs(U(1,2))^2;
  b = -2 * U(1,1) * real(U(1,2));
  c = -2 * U(1,1) * imag(U(1,2));
  d = U(1,1)^2;
  
  A(4,:) = [a b c d];
  
end