function out = pdf_bb(BhvExp,Ns,Bhv)

  % This function calculates the likelihood of the observations
  % represented by the matrix Bhv given the 'true' matrix BhvExp and
  % the number of averaged spectra Ns
  %
  % The calculation is performed according to Sec. 3
  %
  % INPUT VARIABLES:
  %
  % BhvExp is the 'true' 2x2 covariance matrix
  % Ns is the number of spectra averaged non-coherently
  % Bhv is the 2x2 covariance matrix from observations
  %
  % OUTPUT:
  %
  % out is the value of the likelihood function
  %
  % EXAMPLE:
  %
  % BhvExp(1,1) = 2; % B_{hh}
  % BhvExp(2,2) = 1; % B_{vv}
  % BhvExp(1,2) = 0.5 + 1i*0.1; % R_{hv} + 1i*J_{hv}
  % BhvExp(2,1) = conj(BhvExp(1,2));
  %
  % Ns = 10;
  %
  % Bhv(1,1) = 2.1; % \hat{B}_{hh}
  % Bhv(2,2) = 0.9; % \hat{B}_{vv}
  % Bhv(1,2) = 0.55 + 1i*0.05; % \hat{R}_{hv} + 1i*\hat{J}_{hv}
  % Bhv(2,1) = conj(Bhv(1,2));
  %
  % pdf_bb(BhvExp,Ns,Bhv)
  %
  % The output of the code is 1.7071
  
  U  = get_operator_for_sec_specfific_basis(BhvExp);
  Bc = coh_matrix_in_orthogonal_basis_from_formulas(BhvExp,U);
  B  = coh_matrix_in_orthogonal_basis_from_formulas(Bhv,U);
  
  Bcc = squeeze(B(1,1,:));
  Bxx = squeeze(B(2,2,:)); 
  Bre = real(squeeze(B(1,2,:)));
  Bim = imag(squeeze(B(1,2,:)));
  
  sigmax = sqrt(Bc(1,1)/2);
  sigmay = sqrt(Bc(2,2)/2);
  
  fre = pdf_mul(Bre,sigmax,sigmay,Ns);
  fim = pdf_mul(Bim,sigmax,sigmay,Ns);
  
  fx = pdf_power(Bcc,Ns,sigmax);
  fy = pdf_power(Bxx,Ns,sigmay);
  
  out = fx.*fy.*fre.*fim;
  
end