function out = pdf_bc(BhvExp,Ns,Bhh,Zdr,rho,phi)
  
  % This function calculates the likelihood of the observations
  % represented by Bhh Zdr rho and phi given the 'true' matrix BhvExp and
  % the number of averaged spectra Ns
  %
  % The calculation is performed according to Sec. 3
  %
  % INPUT VARIABLES:
  %
  % BhvExp is the 'true' 2x2 covariance matrix
  % Ns is the number of spectra averaged non-coherently
  % Bhh is power for the spectral line in the horizontal channel
  % Zdr is differential reflectivity for the spectral line
  % rho is correlation coefficient for the spectral line
  % phi is differential phase for the spectral line
  %
  % OUTPUT:
  %
  % out is the value of the likelihood function
  %
  % EXAMPLE:
  %
  % BhvExp(1,1) = 2; % B_{hh}
  % BhvExp(2,2) = 1; % B_{vv}
  % BhvExp(1,2) = 0.5 + 1i*0.1; % R_{hv} + 1i*J_{hv}
  % BhvExp(2,1) = conj(BhvExp(1,2));
  %
  % Ns = 10;
  %
  % Bhh = 2.1; % \hat{B}_{hh}
  % Zdr = 2.1; % \hat{Z}_{DR}
  % rho = 0.4; % \hat{\rho}_{HV}
  % phi = 0.0; % \hat{\Phi}_{DP}
  %
  % pdf_bc(BhvExp,Ns,Bhh,Zdr,rho,phi)
  %
  % The output of the code is 0.6247

  U  = get_operator_for_sec_specfific_basis(BhvExp);
  Bc = coh_matrix_in_orthogonal_basis_from_formulas(BhvExp,U);
  
  Bhv(1,1) = Bhh;  
  Bhv(1,2) = Bhh.*rho./sqrt(Zdr).*(cos(phi)+1i*sin(phi));
  Bhv(2,1) = Bhh.*rho./sqrt(Zdr).*(cos(phi)-1i*sin(phi));
  Bhv(2,2) = Bhh./Zdr;
  
  B  = coh_matrix_in_orthogonal_basis_from_formulas(Bhv,U);
  
  Bcc = squeeze(B(1,1,:));
  Bxx = squeeze(B(2,2,:)); 
  Bre = real(squeeze(B(1,2,:)));
  Bim = imag(squeeze(B(1,2,:)));
  
  sigmax = sqrt(Bc(1,1)/2);
  sigmay = sqrt(Bc(2,2)/2);
  
  fre = pdf_mul(Bre,sigmax,sigmay,Ns);
  fim = pdf_mul(Bim,sigmax,sigmay,Ns);
  
  fx = pdf_power(Bcc,Ns,sigmax);
  fy = pdf_power(Bxx,Ns,sigmay);
  
  out = (Bhh./Zdr).^3 .* rho * fx.*fy.*fre.*fim;
  
end